@@ -11,20 +11,20 @@ class RejawClient(object):
         http://code.google.com/p/rejaw/source/browse/trunk/api/ruby/api_client.rb
     """
     
-    def __init__(self, api_key, verbosity=0, hostname='localhost:3000'):
+    def __init__(self, api_key, hostname='localhost:3000'):
         self.api_key = api_key
-        self.verbosity = verbosity
         self.host = hostname
         self.timeout = 120
         
         self.session = None
         
-    def create_session(self):
+    def create_session(self, username=None, password=None):
         """Create a new API session"""
         if self.session:
             raise SessionActive("A session is already active")
             
-        result = self._post('session/create', {'api_key': self.api_key}, False)
+        result = self._post('session/create', {'api_key': self.api_key,
+                                            'username': username, 'password': password}, False)
         if result['succeeded']:
             self.session = result['response']['session']
         return result
@@ -148,6 +148,17 @@ class RejawClient(object):
         the current user is retrived"""
         return self._get('timeline/user', {'page': page, 'username': username, 'filter': filter})
         
+    def search_users(self, query, page=1, per_page=None, detail=None):
+        """Search Rejaw users by keywords"""
+        return self._get('user/search', {'q': query, 'page': page, 'per_page': per_page, 'detail': detail})
+        
+    def search_conversations(self, query):
+        """Search shouts, replies, and, possibly, whispers, by keywords. If
+        an authenticated session id is provided, results may contain whispers
+        (and replies in whispers) that the authenticated user is a member of.
+        Otherwise, results will only contain public shouts and replies in those shouts."""
+        return self._get('conversation/search', {'q': query})
+        
     def observe(self, counter):
         # TODO: Update docstring
         path = "http://%d.%s/%s/%s.json" % (randint(1,100), self.host, API_VERSION, 'event/observe')
