@@ -47,7 +47,7 @@ class ObserverThread(Thread):
 class SampleClient(object):
     prompt = "> "
     def __init__(self, key, username, password, hostname='localhost:3000'):
-        self.client = RejawClient(key, 0, hostname)
+        self.client = RejawClient(key, hostname)
         self.client.create_session()
         self.username = username
         response = self.client.signin(self.username, password)
